#
# spec file for package perl-Net-Jabber
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Net-Jabber
Name:           perl-Net-Jabber
Version:        2.0.0
Release:        1.1
# 2.0 -> normalize -> 2.0.0
%define cpan_version 2.0
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Jabber Perl Library
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RE/REATMON/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
Patch0:         Net-Jabber-2.0-tests.diff
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Net::XMPP) >= 1
Requires:       perl(Net::XMPP) >= 1
Provides:       perl(Net::Jabber) = %{version}
Provides:       perl(Net::Jabber::Client) = %{version}
Provides:       perl(Net::Jabber::Component) = %{version}
Provides:       perl(Net::Jabber::Data) = %{version}
Provides:       perl(Net::Jabber::Debug) = %{version}
Provides:       perl(Net::Jabber::Dialback) = %{version}
Provides:       perl(Net::Jabber::Dialback::Result) = %{version}
Provides:       perl(Net::Jabber::Dialback::Verify) = %{version}
Provides:       perl(Net::Jabber::IQ) = %{version}
Provides:       perl(Net::Jabber::JID) = %{version}
Provides:       perl(Net::Jabber::Key) = %{version}
Provides:       perl(Net::Jabber::Log) = %{version}
Provides:       perl(Net::Jabber::Message) = %{version}
Provides:       perl(Net::Jabber::Namespaces)
Provides:       perl(Net::Jabber::Presence) = %{version}
Provides:       perl(Net::Jabber::Protocol) = %{version}
Provides:       perl(Net::Jabber::Server) = %{version}
Provides:       perl(Net::Jabber::Stanza)
Provides:       perl(Net::Jabber::XDB) = %{version}
Provides:       perl(Test::Builder) = 0.17
Provides:       perl(Test::More) = 0.47
Provides:       perl(Test::Simple) = 0.47
%undefine       __perllib_provides
%{perl_requires}

%description
  Net::Jabber is a convenient tool to use for any perl script that would
  like to utilize the Jabber Instant Messaging protocol.  While not a
  client in and of itself, it provides all of the necessary back-end
  functions to make a CGI client or command-line perl client feasible and
  easy to use.  Net::Jabber is a wrapper around the rest of the official
  Net::Jabber::xxxxxx packages.

  There is are example scripts in the example directory that provide you
  with examples of very simple Jabber programs.


  NOTE: The parser that XML::Stream::Parser provides, as are most Perl
  parsers, is synchronous.  If you are in the middle of parsing a packet
  and call a user defined callback, the Parser is blocked until your
  callback finishes.  This means you cannot be operating on a packet,
  send out another packet and wait for a response to that packet.  It
  will never get to you.  Threading might solve this, but as of the
  writing of this, threading in Perl is not quite up to par yet.  This
  issue will be revisted in the future.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -N

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644
%patch -P0 -p0

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc CHANGES examples README
%license LICENSE.LGPL

%changelog
* Thu Feb  6 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Mon Mar  4 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Jan 20 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Use %%patch0 to fix compilation with rpm-4.19
* Tue Oct 14 2014 jengelh@inai.de
- Use source URLs and remove ancient specfile tags and sections
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Wed Nov 25 2009 meissner@suse.de
- rediffed for fuzz=0
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Tue Aug  9 2005 ro@suse.de
- ignore test errors for the moment
* Mon Aug  1 2005 mjancar@suse.cz
- update to 2.0
- add perl-Authen-SASL and perl-Net-XMPP to Requires
* Tue Mar  2 2004 mjancar@suse.cz
- update to 1.29
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Aug  7 2003 mjancar@suse.cz
- fix tests that depend on certain order of entries
  in a hash (it is random in perl 5.8.1)
* Tue Jul 22 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Tue Jun 17 2003 mjancar@suse.cz
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Wed Dec 18 2002 prehak@suse.cz
- updated to version 1.28
- removed x permissions from nonexecutable example scripts
* Sat Jul 20 2002 prehak@suse.cz
- update to version 1.26
- added perl-Unicode-String to neededforbuild and to Required
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Tue Jan 15 2002 rvasice@suse.cz
- update to version 1.0024
* Wed Aug 15 2001 rvasice@suse.cz
- initial package release (version 1.0022)
